# earwig
# Copyright (C) 2018  Frederic Peters
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.core.urlresolvers import reverse_lazy
from django.contrib import messages
from django.shortcuts import redirect
from django.utils.translation import ugettext_lazy as _
from django.views.generic import ListView, CreateView, DetailView

from ..sounds.models import Channel, Sound


class Homepage(ListView):
    model = Sound
    paginate_by = 10
    template_name = 'earwig/manager_home.html'

    def get_queryset(self, **kwargs):
        return self.model.objects.filter(status='').select_related()

homepage = Homepage.as_view()


class ChannelAdd(CreateView):
    model = Channel
    fields = ('title', 'channel_url', 'feed_url', 'policy')
    template_name = 'earwig/manager_channel_add.html'
    success_url = reverse_lazy('earwig-manager-homepage')

channel_add = ChannelAdd.as_view()


class SoundPublishView(DetailView):
    model = Sound

    def get(self, *args, **kwargs):
        self.get_object().publish()
        messages.success(self.request, _('%s has been published.') % self.get_object())
        return redirect('earwig-manager-homepage')

sound_publish = SoundPublishView.as_view()


class SoundRejectView(DetailView):
    model = Sound

    def get(self, *args, **kwargs):
        self.get_object().reject()
        messages.warning(self.request, _('%s has been rejected.') % self.get_object())
        return redirect('earwig-manager-homepage')

sound_reject = SoundRejectView.as_view()
